Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1035)

Unified Diff: pkg/analyzer_cli/bin/analyzer.dart

Issue 1646413003: Add hook to command-line analyzer similar to server (Closed) Base URL: https://github.com/dart-lang/sdk.git@master
Patch Set: Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | pkg/analyzer_cli/lib/plugin/analysis/resolver_provider.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analyzer_cli/bin/analyzer.dart
diff --git a/pkg/analyzer_cli/bin/analyzer.dart b/pkg/analyzer_cli/bin/analyzer.dart
index b0a32feee9eabf0503e2c5bdc853349d12530738..3172b0fab730f9adbc26652bfc058dcb5d13936a 100644
--- a/pkg/analyzer_cli/bin/analyzer.dart
+++ b/pkg/analyzer_cli/bin/analyzer.dart
@@ -3,14 +3,10 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-import 'package:analyzer_cli/src/driver.dart';
+import 'package:analyzer_cli/starter.dart';
-
-
-
-/// The entry point for the analyzer.
+/// The entry point for the command-line analyzer.
void main(List<String> args) {
- var starter = new Driver();
+ CommandLineStarter starter = new CommandLineStarter();
starter.start(args);
-
}
« no previous file with comments | « no previous file | pkg/analyzer_cli/lib/plugin/analysis/resolver_provider.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698